<!DOCTYPE html>
<html lang="en">
<head>
 
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
 
    <title>PDO: Update a Record</title>
 
	 <!-- Bootstrap CSS -->
	<link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css"
        integrity="sha384-ggOyR0iXCbMQv3Xipma34MD+dH/1fQ784/j6cY/iJTQUOhcWr7x9JvoRxT2MZw1T" crossorigin="anonymous">
 
</head>
<body>


    <!-- container -->
    <div class="container">

        <div class="page-header mt-3">
            <h1>Update Product</h1>
        </div>

		<?php
		// get passed parameter value, in this case, the record ID
		// isset() is a PHP function used to verify if a value is there or not
		$id=isset($_GET['id']) ? $_GET['id'] : die('ERROR: Record ID not found.');

		//include database connection
		include 'config/database.php';

		// check if form was submitted
		if($_POST){

			try{

				// write update query
				// in this case, it seemed like we have so many fields to pass and
				// it is better to label them and not use question marks
				$query = "UPDATE products
							SET name=:name, description=:description, price=:price
							WHERE id = :id";

				// prepare query for excecution
				$stmt = $con->prepare($query);

				// sanitize
				$name=htmlspecialchars(strip_tags($_POST['name']));
				$description=htmlspecialchars(strip_tags($_POST['description']));
				$price=htmlspecialchars(strip_tags($_POST['price']));
				$id=htmlspecialchars(strip_tags($id));

				// bind the parameters
				$stmt->bindParam(':name', $name);
				$stmt->bindParam(':description', $description);
				$stmt->bindParam(':price', $price);
				$stmt->bindParam(':id', $id);

				// Execute the query
				if($stmt->execute()){
					echo "<div class='alert alert-success'  >Record was updated.</div>";
				}else{
					echo "<div class='alert alert-danger' role='alert'>Unable to update record. Please try again.</div>";
				}

			}

			// show errors
			catch(PDOException $exception){
				die('ERROR: ' . $exception->getMessage());
			}
		}

		// read current record's data
		try {
			// prepare select query
			$query = "SELECT id, name, description, price FROM products WHERE id = ? LIMIT 0,1";
			$stmt = $con->prepare( $query );

			// this is the first question mark
			$stmt->bindParam(1, $id);

			// execute our query
			$stmt->execute();

			// store retrieved row to a variable
			$row = $stmt->fetch(PDO::FETCH_ASSOC);

			// values to fill up our form
			$name = $row['name'];
			$description = $row['description'];
			$price = $row['price'];
		}

		// show error
		catch(PDOException $exception){
			die('ERROR: ' . $exception->getMessage());
		}
		?>
		<form action='update.php?id=<?php echo htmlspecialchars($id); ?>' method='post' class="mt-3">
		  
			<table class="table table-hover mt-3">
			<tr>
				<th width="20%">Name</th>
				<td width="80%"> <input type="text" name='name' id='name' class="form-control" value="<?php echo htmlspecialchars($name, ENT_QUOTES);  ?>" ></td>
			</tr>
			<tr>
				<th>Description</th>
				<td><textarea name='description' id='description' class='form-control'> <?php echo htmlspecialchars($description, ENT_QUOTES);  ?> </textarea></td>
			</tr>
			<tr>
				<th>Price</th>
				<td><input type='text' name='price' id='price' class='form-control' value="<?php echo htmlspecialchars($price, ENT_QUOTES);  ?>"/></td>
			</tr>
			<tr>
				<td colspan="2">
					<button type="submit" class="btn btn-primary float-right">Save Changes</button>
		  			<a href='index.php' class='btn btn-danger mr-3 float-right'>Back to read products</a>
				</td>
			</tr>
		</table>
		</form>

	</div> <!-- end .container -->

<!-- javascript for bootstrap -->
<script src="https://code.jquery.com/jquery-3.3.1.slim.min.js"
    integrity="sha384-q8i/X+965DzO0rT7abK41JStQIAqVgRVzpbzo5smXKp4YfRvH+8abtTE1Pi6jizo" crossorigin="anonymous">
</script>
 
<script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.js"
    integrity="sha384-UO2eT0CpHqdSJQ6hJty5KVphtPhzWj9WO1clHTMGa3JDZwrnQq4sF86dIHNDz0W1" crossorigin="anonymous">
</script>
 
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js"
    integrity="sha384-JjSmVgyd0p3pXB1rRibZUAYoIIy6OrQ6VrjIEaFf/nJGzIxFDsf4x0xIM+B07jRM" crossorigin="anonymous">
</script>
</body>
</html>
